// Configuration
const margin = {
  top: 10,
  right: 10,
  bottom: 100,
  left: 60
};
const width = 1200 - margin.left - margin.right;
const height = 500 - margin.top - margin.bottom;

// Chargement des données
Promise.all([
  d3.csv('./data/2016.csv'),
  d3.json('./data/fr-CA.json')
]).then(initialize);


/**
 * Initialise le graphique
 *
 * @param data      Données à utiliser
 * @param locale    Les paramètres locaux à utiliser
 */
function initialize([data, locale]) {
  // Formattage des temps selon le format français (Canada)
  d3.timeFormatDefaultLocale(locale);

  // ***** Traitement des données *****
  const color = d3.scaleOrdinal()
    .domain(d3.keys(data[0]).filter(key => key !== 'Date'))
    .range(['#1f77b4', '#ff7f0e', '#2ca02c', '#d62728', '#9467bd',
      '#8c564b', '#e377c2', '#7f7f7f', '#bcbd22', '#000']);

  // Conversion des dates du fichier CSV en objet Date
  const parser = d3.timeParse('%d/%m/%y');
  data.forEach(d => {
    d.Date = parser(d.Date);
  });

  // Création des sources à utiliser pour votre line chart
  const sources = color.domain().map(name => {
    return {
      name: name,
      values: data.map(d => {
        return {
          date: d.Date,
          count: +d[name]
        };
      })
    };
  });

  // ***** Définitions des échelles et des axes x et y *****

  // TODO
  // Définir l'échelle de X comme une échelle de temps. Utiliser comme domaine la date minimale
  // et celle maximale que vous avez dans vos données. Le "range" doit être entre 0 et 'width'.

  // TODO
  // Définir l'échelle de Y comme une échelle linéaire. Utiliser comme domaine 0 et la valeur maximale
  // du nombre de vélos ayant circulé sur une rue pour une date précise. Le "range" doit être entre 0
  // et 'height'.

  // TODO
  // Définir les axes X (axe horizontal) et Y (axe vertical)

  // ***** Création des éléments *****
  const svg = d3.select('body')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom);

  const g = svg.append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`);

  // TODO
  // Initialiser la fonction "d3.line" avec les bons paramètres


  // TODO
  // Dessiner les lignes pour chacune des rues et la moyenne en utilisant la variable 'g'
  // comme sélection de base


  // TODO
  // Dessiner les axes en utilisant la variable 'g' comme sélection de base. N'oubliez pas de définir
  // un nouveau groupe pour chacun des axes.

  // TODO
  // Dessiner la légende (noms de rue et carrés de couleurs)

}
